# TOPSIS


Submitted By: **Ratish 101803004**

***

## What is TOPSIS?

**T**echnique for **O**rder **P**reference by **S**imilarity to **I**deal **S**olution 
(TOPSIS) originated in the 1980s as a multi-criteria decision making method.
TOPSIS chooses the alternative of shortest Euclidean distance from the ideal solution, 
and greatest distance from the negative-ideal solution. 

<br>

## How to install this package:
```
>> pip install TOPSIS-RATISH-101803004
```


### In Command Prompt
```
>> topsis data.csv "1,1,1,1" "+,+,-,+" result.csv
```

